@@ -23,7 +23,7 @@ TUBE_STATIONS = 'Closed stations'
 LINES = ['Bakerloo', 'Central', 'Circle', 'District', 'Hammersmith & City', 'Jubilee', 'Metropolitan', 'Northern', 'Piccadilly', 'Victoria', 'Waterloo & City']
 
 LINE_REPLACEMENTS = [['H\'smith', 'Hammersmith']]
-STATION_REPLACEMENTS = [['Bank','Bank & Monument'], ['Monument','Bank & Monument'], ['Station', '']]
+STATION_REPLACEMENTS = [['Bank','Bank & Monument'], ['Monument','Bank & Monument'], ['Station', ''], ['Earls Court', 'Earl\'s Court']]
 INFO_REPLACEMENTS = [['</p><P>', ''], [' between ', ' from '], [' and ', ' to ']]
 
 def parse_routeinfo(msg):
@@ -159,7 +159,7 @@ def get(fname=OUTFILE):
 	if delays == "":
 		delays = ";"
 
-	if (not path.exists(fname)) or outdated(fname) or old(fname):
+	if (not path.exists(fname)) or outdated(fname):
 		try:
 			print "Writing file..."
 			f = open(fname, 'w')
