@@ -109,6 +109,16 @@ def cleanString(string):
 
 if os.path.exists(DATA_FILE):
 	[Station, Line] = cPickle.load(open(DATA_FILE, 'r'))
+	FullLine = {}                                                  
+	for superline in Line[LINE_GROUPS]:                            
+		for line_1 in Line[LINE_GROUPS][superline]:            
+			FullLine[line_1] = Line[LINE_STOP][line_1]     
+			for line_2 in Line[LINE_GROUPS][superline]:    
+				if Line[LINE_STOP][line_1][0] == Line[LINE_STOP][line_2][-1]:
+					FullLine[line_1][0:0] = Line[LINE_STOP][line_2][:-1]
+				if Line[LINE_STOP][line_1][-1] == Line[LINE_STOP][line_2][0]:
+					FullLine[line_1][-1:-1] = Line[LINE_STOP][line_2][1:]
+	[Station, Line] = cPickle.load(open(DATA_FILE, 'r'))
 else:
 	if not os.path.exists(DATA_DIR):
 		print "Error: Neither data file nor database found."
@@ -195,11 +205,14 @@ def get_closures():
 			if Line[LINE_GROUPS].has_key(part[0]):
 				for line in Line[LINE_GROUPS][part[0]]:
 					try:
-						closed_from = min(Line[LINE_STOP][line].index(cleanString(part[1])), Line[LINE_STOP][line].index(cleanString(part[2])))
-						closed_to = max(Line[LINE_STOP][line].index(cleanString(part[1])), Line[LINE_STOP][line].index(cleanString(part[2])))
+						closed_from = min(FullLine[line].index(cleanString(part[1])), FullLine[line].index(cleanString(part[2])))
+						closed_to = max(FullLine[line].index(cleanString(part[1])), FullLine[line].index(cleanString(part[2])))
+						#closed_from = min(Line[LINE_STOP][line].index(cleanString(part[1])), Line[LINE_STOP][line].index(cleanString(part[2])))
+						#closed_to = max(Line[LINE_STOP][line].index(cleanString(part[1])), Line[LINE_STOP][line].index(cleanString(part[2])))
 						for i in range(closed_to - closed_from):
+							idx = Line[LINE_STOP][line].index(FullLine[line][i + closed_from])
 							if len(part) == 3:
-								Station[STATION_TIMES][line][i + closed_from] = INFINITY
+								Station[STATION_TIMES][line][idx] = INFINITY
 							else:
 								Station[STATION_TIMES][line][i + closed_from] += BUS_PENALTY
 								Station[STATION_TIMES][line][i + closed_from] *= -1
@@ -563,7 +576,8 @@ def main():
 							if (event.x >= x) and (event.x <= x + dx) and (event.y >= y) and (event.y <= y + dy):
 								stop = route.plan[0][i+1]
 								hildon.hildon_banner_show_information(win, 'qgn_note_infoprint', route.guide[i])
-								data.scroll_to(int((Station[STATION_COORDS][stop][0] + Station[STATION_COORDS][stop][2])/2*MAP_SCALE), int((Station[STATION_COORDS][stop][1] + Station[STATION_COORDS][stop][3])/2*MAP_SCALE))
+								if len(Station[STATION_COORDS][stop]) == 4:
+									data.scroll_to(int((Station[STATION_COORDS][stop][0] + Station[STATION_COORDS][stop][2])/2*MAP_SCALE), int((Station[STATION_COORDS][stop][1] + Station[STATION_COORDS][stop][3])/2*MAP_SCALE))
 		widget.oldtime = event.time
 
 	def showdialog(title, route):
